Chromium Code Reviews

Unified Diff: chrome/browser/shell_integration.h

Issue 1588733005: Reduce MigrateChromiumShortcuts to only handling taskbar pins. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@a2_gab_more_metro_cleanup
Patch Set: Created 4 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments.
Jump to:
View side-by-side diff with in-line comments
« no previous file with comments | « no previous file | chrome/browser/shell_integration_win.cc » ('j') | chrome/browser/shell_integration_win.cc » ('J')
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/browser/shell_integration.h
diff --git a/chrome/browser/shell_integration.h b/chrome/browser/shell_integration.h
index 7073b88f8097b49e3022bcc0c0f78e2f0fe7f990..cfd616201a5dabbfe0faaf45bbd66c64da2d4f9e 100644
--- a/chrome/browser/shell_integration.h
+++ b/chrome/browser/shell_integration.h
@@ -155,20 +155,19 @@ class ShellIntegration {
static base::string16 GetAppListAppModelIdForProfile(
const base::FilePath& profile_path);
// Migrates existing chrome shortcuts by tagging them with correct app id.
// see http://crbug.com/28104
- static void MigrateChromiumShortcuts();
+ static void MigrateChromiumTaskbarPins();
grt (UTC plus 2) 2016/01/14 19:51:12 wdyt of getting rid of "Chromium" here? or changin
gab 2016/01/15 02:27:22 Done.
// Migrates all shortcuts in |path| which point to |chrome_exe| such that they
- // have the appropriate AppUserModelId. Also clears the dual_mode property
- // from shortcuts that previously had it if requested by |clear_dual_mode|.
+ // have the appropriate AppUserModelId. Also clears legacy dual_mode property
grt (UTC plus 2) 2016/01/14 19:51:12 nit: "clears the legacy"
gab 2016/01/15 02:27:22 Done.
+ // from shortcuts with the default chrome app id.
// Returns the number of shortcuts migrated.
// This method should not be called prior to Windows 7.
// This method is only public for the sake of tests and shouldn't be called
// externally otherwise.
static int MigrateShortcutsInPathInternal(const base::FilePath& chrome_exe,
- const base::FilePath& path,
- bool clear_dual_mode);
+ const base::FilePath& path);
// Returns the path to the Start Menu shortcut for the given Chrome.
static base::FilePath GetStartMenuShortcut(const base::FilePath& chrome_exe);
« no previous file with comments | « no previous file | chrome/browser/shell_integration_win.cc » ('j') | chrome/browser/shell_integration_win.cc » ('J')
@@ -155,20 +155,19 @@ class ShellIntegration {
static base::string16 GetAppListAppModelIdForProfile(
const base::FilePath& profile_path);
- // Migrates existing chrome shortcuts by tagging them with correct app id.
+ // Migrates existing chrome taskbar pins by tagging them with correct app id.
// see http://crbug.com/28104

Powered by Google App Engine